@@ -22,15 +22,14 @@ SvgCreator::SvgCreator(QObject *parent, const QVariantList &args)
 KIO::ThumbnailResult SvgCreator::create(const KIO::ThumbnailRequest &request)
 {
     QSvgRenderer r(request.url().toLocalFile());
-    if ( !r.isValid() )
+    if (!r.isValid())
         return KIO::ThumbnailResult::fail();
 
     // render using the correct ratio
-    const double ratio = static_cast<double>(r.defaultSize().height()) /
-                         static_cast<double>(r.defaultSize().width());
+    const double ratio = static_cast<double>(r.defaultSize().height()) / static_cast<double>(r.defaultSize().width());
 
-    int w = request.targetSize().width();
-    int h = request.targetSize().height();
+    int w = request.targetSize().width() * request.devicePixelRatio();
+    int h = request.targetSize().height() * request.devicePixelRatio();
 
     if (w < h)
         h = qRound(ratio * w);
@@ -40,7 +39,7 @@ KIO::ThumbnailResult SvgCreator::create(const KIO::ThumbnailRequest &request)
     QImage i(w, h, QImage::Format_ARGB32_Premultiplied);
     i.fill(0);
     QPainter p(&i);
-    r.render(&p);
+    r.render(&p, QRectF(QPointF(0, 0), QSizeF(h, w)));
 
     return KIO::ThumbnailResult::pass(i);
 }
